"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const BaseCommand_1 = require("../../application/BaseCommand");
class MakeSchemas extends BaseCommand_1.default {
    constructor() {
        super(...arguments);
        this.signature = 'make:schemas';
        this.configKey = 'make.schemas';
    }
    async run() {
        this.logger.comet('Generating JSON schema files...');
        const { args, flags } = this.parse(MakeSchemas);
        const file = await this.loadFile(args);
        if (flags.output) {
            this.configRepository.set(`commands.${this.configKey}.output`, flags.output);
        }
        const specification = await this.parseSpec(file);
        await this.execute(specification);
    }
    async execute(specification) {
        this.logger.spin('Creating JSON Schemas...');
        await this.runPlugins(specification);
        this.logger.succeed('JSON Schemas created');
    }
}
exports.default = MakeSchemas;
MakeSchemas.description = 'Parse an API specification, and automatically generate JSON schemas';
MakeSchemas.examples = [
    '$ comet make:schemas api.json',
];
MakeSchemas.args = [
    {
        name: 'input',
        required: true,
        description: 'relative or absolute path to the input file (your API specification)',
    },
];
MakeSchemas.flags = {
    help: command_1.flags.help({ char: 'h' }),
    output: command_1.flags.string({
        char: 'o',
    }),
};
//# sourceMappingURL=schemas.js.map