"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const signale_1 = require("signale");
const Ora = require("ora");
const table = require('tty-table');
const options = {
    disabled: false,
    interactive: false,
    stream: process.stdout,
    scope: 'comet',
    types: {
        comet: {
            badge: '🌠',
            color: 'cyanBright',
            label: 'comet',
        },
    },
};
class Logger {
    constructor() {
        this.console = new signale_1.Signale(options);
        this.spinner = new Ora({ spinner: 'star' });
    }
    comet(message) {
        this.console.comet(message);
    }
    spin(message) {
        this.spinner.text = message;
        if (this.spinner.isSpinning === false) {
            this.spinner.start();
        }
    }
    succeed(message) {
        if (this.spinner.isSpinning === true) {
            this.spinner.succeed(message);
        }
    }
    fail(message) {
        if (this.spinner.isSpinning === true) {
            this.spinner.fail(message);
        }
    }
    warn(message) {
        if (this.spinner.isSpinning === true) {
            this.spinner.warn(message);
        }
    }
    printWarnings(warnings) {
        const tb = table([
            {
                value: 'Line',
                width: 10,
            },
            {
                value: 'Message',
                width: 60,
                color: 'yellow',
            },
            {
                value: 'Code',
                width: 20,
            },
        ], warnings, {
            borderStyle: 1,
            paddingBottom: 0,
            headerColor: 'yellow',
            headerAlign: 'left',
            color: 'white',
            align: 'left',
        });
        console.log(tb.render());
    }
    printErrors(errors) {
        const tb = table([
            {
                value: 'Line',
                width: 10,
            },
            {
                value: 'Message',
                width: 60,
                color: 'red',
            },
            {
                value: 'Code',
                width: 20,
            },
        ], errors, {
            borderStyle: 1,
            paddingBottom: 0,
            headerColor: 'red',
            headerAlign: 'left',
            color: 'white',
            align: 'left',
        });
        console.log(tb.render());
    }
}
exports.default = Logger;
//# sourceMappingURL=Logger.js.map